                                 %OBJECTIVES

%To estimate the C02 air-water flux.

%To test different numerical schemes used to estimate the flux.

%To test different equations used to estimate the influence of such factors
%as air and water temperature, air presure, salinity, air velocity, 
%water velocity and depth.

%--------------------------------------------------------------------------
                                %CALCULUS

for t=1:size(Ta,2)

    Hs_   = Hs(t);
    Lp_   = Lp(t);
    P_    = P(t);
    psi_m_= psi_m(t);
    S_    = S(t);
    Ta_   = Ta(t);
    Tw_   = Tw(t);
    uz_   = uz(t);
    u_    = u(t);
    vhf_  = vhf(t);
    w_    = w(t);
    Wp_   = Wp(t);
    z_    = z(t);
    za_   = za(t);
    z0_   = z0(t)/1000;
        

    %Conversion of CO2 air concentration from partial pressure (ppm) to
    %mol/m^3 if originally given in ppm.
    if isnan(Cg)==0
        Cg_    = Cg(t);
    elseif isnan(Cg)==1
        Tka    = 273.15+Ta_;                                        %Kelvin
        Pascal = P_*101325.01;                                          %Pa
        Cg_    = Cgppm(t)*Pascal/(10^6*R*Tka);                     %mol/m^3
    end

    % Conversion of CO2 water concentration from equivalent atmospheric 
    %partial pressure in equilibrium (ppm) to mol/m^3 if originally given 
    %in ppm.
    if isnan(Cl)==0
        Cl_  = Cl(t);
    elseif isnan(Cl)==1
        Tka  = 273.15+Ta_;
        Tkw  = 273.15+Tw_;
        run kHExe
        kHcp = 12.1866/(Tka*kH);                               %mol/(L*atm)
        Cl_  = Clppm(t)*kHcp*P_*10^-3;                             %mol/m^3
    end
    
    % Estimates air-side transfer velocity
    T      = Ta_;
    Tka    = 273.15+Ta_;                       %Celsius to Kelvin conversor
    Tcool  = 0; %!!! implement 'cool skin algorithm'!!!
    Twarm  = 0; %!!! implement 'warm layer algorithm'!!!
    Tskin  = Tw_+Tcool+Twarm;
    Tkskin = 273.15+Tskin;
    run kaExe
    if sum(strcmp(ka,{'Lis73' 'Dea91' 'Sea02' 'Joh10'}))==1 && za~=10
        'error: ka numerical scheme requires 10m wind measurement heigth'
        break
    end

    %Estimates Henry's constant and water-side transfer velocity
    T     = Tskin;
    Tkw   = Tkskin;                            %Celsius to Kelvin conversor
    run kHExe
    run kwExe
    if sum(strcmp(kw,{'Bea04' 'Cea96' 'L&M86' 'McG01' 'Nea00' 'R&C01' ...
                                          'Sea07' 'Wan92'}))==1 && za~=10
        'error: kw numerical scheme requires 10m wind measurement heigth'
        break
    end

    % Estimates the flux
    run FluxExe

%--------------------------------------------------------------------------

                             % SAVE and CLEAN

    Parameters(t).air.temperature=Ta_;
    Parameters(t).air.pressure=P_;
    Parameters(t).air.wind=uz_;
    Parameters(t).air.CO2=Cg_;
    Parameters(t).water.temperature=Tw_;
    Parameters(t).water.salinity=S_;
    Parameters(t).water.current=w_;
    Parameters(t).water.depth=z_;
    Parameters(t).water.CO2=Cl_;

    NumScheme.flux=FluxNumScheme;
    NumScheme.flux_units=fluxunit;
    NumScheme.Ka=KaScheme;
    NumScheme.CD=DragCoef;
    NumScheme.Atm_Stability=AtmStbScheme;
    NumScheme.Richardson_number=RichardsonScheme;
    NumScheme.Kw=KwScheme;
    NumScheme.SchmidtNumber=SchmidtScheme;
    NumScheme.Dw=DwScheme;

    Results(t).Henry_constant=kH;
    Results(t).transfer_velocity.friction_velocity=u_;
    Results(t).transfer_velocity.roughness_length=z0_;  
    Results(t).transfer_velocity.water.wind=kwWind;
    Results(t).transfer_velocity.water.current=kwCurrent;
    Results(t).transfer_velocity.water.alfa=Alfa;
    Results(t).transfer_velocity.water.kw=kw;
    Results(t).Flux.water_based=Fw;
    Results(t).Delta_CO2=Cg_/kH-Cl_;
    
    try
        Results(t).transfer_velocity.water.Dw=Dw;
    catch
        Results(t).transfer_velocity.water.Dw=NaN;
    end

    try
        Results(t).transfer_velocity.air=ka;
        Results(t).transfer_velocity.total_air_based=Ka;
        Results(t).transfer_velocity.total_water_based=Kw;
        Results(t).Flux.air_based=Fa;
    catch
        Results(t).transfer_velocity.air=NaN;
        Results(t).transfer_velocity.total_air_based=NaN;
        Results(t).transfer_velocity.total_water_based=NaN;
        Results(t).Flux.air_based=NaN;
    end
end

clear('-regexp','^A|^C|^Dw|^E|^F|^H|^K|^L|Lee$|^M|^Rb|^Rh|^Ri|^S|^T|^U|^V')
clear('-regexp','^W|^a|^b|^d|^e|^h|^k|^p|^r|^t|^u|^v|^w|^z')
clear Bw c cp Da DragCoef fTS fluxunit g gamma_m i msi msj n Omega  
clear P P_ Pascal R t y_at_k
