                              %OBJECTIVES

%To declare the chosen numerical options to the calculus files  

%--------------------------------------------------------------------------

                        %GAS FLUX MODEL OPTIONS

% Flux numerical scheme: 'DoubleLayer' or 'SingleLayer'
FluxNumScheme = 'DoubleLayer';

% Flux units: (1) mol*m^-2*s^-1; (2) mmol*m^-2*h^-1; (3) mmol*m^-2*d^-1
fluxunit = 3;

% Air transfer velocity (ka)
    %'Joh10': Johnson (2010)
    %'Dea91': Duce et al (1991)
    %'Lis73': Liss (1973)
    %'M&Y83': Mackay & Yeun (1983), for wind speeds between 5 and 22 m/s
    %'Sea02': Shahin et al 2002
    %'J_COA': Johnson (2010) adaptation of COARE
KaScheme = 'M&Y83';

% Drag coefficient
    %'Dea91': Duce et al (1991);
    %'M&Y83': Mackay & Yeun (1983)
    %'Smi80': Smith (1980);
    %'T&Y01': Taylor and Yelland (2001)
DragCoef ='Smi80';

%method for the estimate of atmospheric stability effect:
    %'Le97B' : Lee (1997) adapted to Businger et al (1971)
    %'Le97D' : Lee (1997) adapted to Dyer (1974)
    %'Stu88' : Stull (1988)
    %'S&R75' : Sethuraman and Raynor (1975)
AtmStbScheme = 'Stu88';

%method for the estimate of the bulk Richardson number:
    %'Lee97' : Lee (1997)
    %'Stu88' : Stull (1988)
RichardsonScheme = 'Stu88';
    
% Water transfer velocity (kw_wind)
    %'Bea04': Borges et al (2004)
    %'Cea96': Carini et al (1996)
    %'L&M86': Liss & Merlivat (1986)
    %'M&Y83': Mackay & Yeun (1983)
    %'MY83W': Mackay & Yeun (1983) adapted from Wolff and Heijde (1982)
    %'McG01': McGillis et al (2001)
    %'Nea00': Nightingale et al (2000)
    %'R&C01': Raymond & Cole (2001)
    %'Sea07': Sweeney et al (2007)
    %'Wan92': Wanninkhof (1992)
    %'Zea03': Zhao et al (2003) dependent on u_
    %'ZoJ03': Zhao et al (2003) on data from Jhne et al (1985)
    %'ZRb03': Zhao et al (2003) dependent on u_ and whitecap
KwScheme = 'ZRb03';

% Chemical enhancement of water transfer velocity (alfa)
    %'Bea04': Borges et al (2004)
    %'Cea96': Carini et al (1996)
    %'Joh10': Johnson (2010)
    %'R&C01': Raymond Cole (2001)
SchmidtScheme = 'Joh10';

% Water difusivity scheme (Dw)
    %'H&L74': Hayduk & Laudie (1974)
    %'H&M82': Hayduk & Minhas (1982)
    %'W&C55': Wilkie & Chang  (1955)
DwScheme = 'W&C55';

%--------------------------------------------------------------------------

        % DECOMPOSITION of the DIFFERENCE in the FLUXES (DDF) OPTIONS


%Increments in the variables for the numerical estimates of the partial
%derivatives.
%The delta(i)=NaN forces the software to automatically estimate it as:
%delta(i)=(x(i,b)-x(i,a))/n(i).
%     [Cg  Ta  P  uz  Wp  Hs  Lp  z0  vhf psi u_  za  Cl  Tw  S  w   z  ]
delta=[1   NaN 1  1   1   1   1   NaN NaN NaN NaN 1   1   1   1  NaN NaN];

%Number of steps taken forward or bacward for the numerical estimates of 
%the partial derivatives.
%     [Cg  Ta  P  uz  Wp  Hs  Lp  z0  vhf psi u_  za  Cl  Tw  S   w   z ]
n=    [2   2   1  2   0   0   0   3   0   3   0   0   1   3   1   2   2 ];
%     [2   2   1  3                       x   x   x   1   3   1   2   2 ];

%Order of the partial derivatives and terms.
%     [Cg  Ta  P  uz  Wp  Hs  Lp  z0  vhf psi u_  za  Cl  Tw  S   w   z]
theta=[2   2   1  2   0   0   0   3   0   3   0   0   1   3   1   2   2];

%Point of estimate of partial derivatives and terms
%         [Cg  Ta  P  uz  Wp  Hs  Lp  z0  vhf psi u_  za  Cl  Tw  S  w  z]
dfdx_at_k=[0   0   0  0   0   0   0   0   0   0   0   0   0   0   0  0  0];


%Current speed units: (1)m/s (2)cm/s, (3)dm/s, (4)m/min, (5)hm/h or (6)km/h
w_units=3;

%Depth units: (1) dm, (2) m, (3) dam or (4) hm
z_units=3;

%friction velicity units: (1)m/s, (2)dm/s or (3)km/h
u_units=3;

%Peak wave length units: (1) m, (2) dam or (3) hm
Lp_units=1;

%Peak wave period units: (1) s or (2) 10s
Wp_units=1;

%Roughness length units: (1) mm/10, (2) mm, (3) cm or (4) dm
z0_units=2;

%Significant wave height units: (1) cm, (2) dm or (3) m
Hs_units=3;

%Wind speed units: (1)m/s or (2)km/h
uz_units=1;

%Use Psi_m in the DDF analysis to explicit Atm Stb effect: 0(yes) or 1(no)
psi_m_DDF=1;

