                            % OBJECTIVES

%Estimates the air side transfer velocity for given temperatures (T),
% air pressures (P) and wind (uz).

%--------------------------------------------------------------------------

                             % CALCULUS:
       %air temperature and pressure on air transfer velocity

                             
% Diffusion coefficient of CO2 in air (cm^2/s) by Fuller et al (1966)
Mr=(Ma+Mb)/(Ma*Mb);
Da=(0.001*Tka.^1.75.*sqrt(Mr))./(P_.*(Va^(1/3)+Vb^(1/3))).^2;

%Dynamic viscosity of air (N.s/m^2)
Etaa=Sv0+Sv1*T+Sv2*T.^2+Sv3*T.^3+Sv4*T.^4;                     

%Air density (kg/m^3)
Rhoa=Sd0+Sd1*T+Sd2*T.^2+Sd3*T.^3;                               

%Kinematic viscosity of air converted from m^2/s to cm^2/s
Upsa=Etaa./Rhoa*10000;

%Schmidt number in air (scalar)
Sca=Upsa./Da;

%--------------------------------------------------------------------------
                            %CALCULUS
                     % Friction velocity (m/s)

%1. roughness length estimated from wave height and wave length
if isnan(z0_)==1 && isnan(Hs_)==0 && isnan(Lp_)==0
    z0_=Aw*Hs_*(Hs_/(Omega*Lp_))^Bw;                                     %m
end

%2.1. friction velocity estimated from drag coefficient (CD)
if isnan(u_)==1 && isnan(z0_)==1 && ...
              sum(strcmp(KaScheme,{'Joh10' 'J_COA' 'M&Y83'}))>=1
                 
    switch DragCoef
        case 'Dea91'
            CD=1.3*10^-3;
        case 'M&Y83'
            CD=4*uz_./(10^4);
        case 'Smi80'
            CD=(6.1+0.63.*uz_)./(10^4);
        case 'T&Y01'
            CD=(0.87+0.0752*uz_-0.000661*uz_^2)/10^3;
    end
    
    u_=uz_.*sqrt(CD);
    
    if za_~=10;
       ['error at t=' num2str(t) ': invalid CD used. Wind estimated at '...
                                                         num2str(za) 'm']
    end
   
%2.2. friction velocity estimated from Wind Log-Linear Profile with
% Monin-Obukhof length (L) estimated from

%2.2.1. vertical heat flux (vhf)
elseif isnan(u_)==1 && isnan(z0_)==0 && isnan(vhf_)==0 
    'error: finish implementation of Atm Stb from vhf'
    Tp=Tka.*(1000./P_).^(R/cp);
    MO_L_=-u_.^3*cp.*rhoa*1000.*Tp./(Karman*g*vhf_);
    
%2.2.2. Sonic method
%elseif  isnan(u_)==1 && isnan(z0_)==0 && isnan(vhf_)==1 % && ...
    
%2.2.3. bulk Richardson number (Rib)
elseif  isnan(u_)==1 && isnan(z0_)==0 && isnan(vhf_)==1
    
    du    = uz_;
    dz    = (za_-z0_);
    
    %water-vapor saturation mixing ratio at heigth z
    esat  = 0.61078*exp(17.2694*(Tka-273.16)/(Tka-35.86));
    rsatz = 0.622*esat/(101.32501*P_-esat);
    
    %relative humidity at z
    hrz   = 0.7;
    
    %liquid-water saturation mixing ratio at heigth z
    rL    = 0;
    
    %potential temperature at heigth z
    Tpz   = Tka*(1000/(P_*1013.25))^0.284;
    
    %virtual potential temperature at heigth z
    Tpvz  = Tpz*(1+0.61*rsatz*hrz-rL);
    
    %water-vapor saturation mixing ratio at heigth z0
    esat  = 0.61078*exp(17.2694*(Tskin)/(Tkskin-35.86));
    rsat0 = 0.622*esat/(101.32501*P_-esat);
    
    %relative humidity at z0
    hr0   = 1;
    
    %potential temperature at z0
    Tp0   = Tkskin*(1000/(P_*1013.25))^0.284;
    
    %virtual potential temperature at z0
    Tpv0  = Tp0*(1+0.61*rsat0*hr0-rL);
    
    %bulk Richardson number according to Stull 1988
    if strcmp(RichardsonScheme,'Stu88')==1 && isnan(psi_m_)==1
        dTv = Tpvz-Tpv0;
        Rib = g*dTv*dz/(Tpvz*du^2);
    
    %bulk Richardson number according to Lee 1997
    elseif strcmp(RichardsonScheme,'Lee97')==1 && isnan(psi_m_)==1
        Tp0 = Tkskin*(1000/(P_*1013.25))^(R/cp);
        Tpz = Tka*(1000/(P_*1013.25))^(R/cp);
        dTp = Tpz-Tp0;
        Rib = g*dTp*dz/(Tpz*du^2);
    
    end
    
    %Wind Log-Linear Profile
    if strcmp(AtmStbScheme,'Le97B')==1 && isnan(psi_m_)==1

        if Rib<0
            m_Lee   = (0.05-0.11)/(10^4-10);
            b_Lee   = 0.11-m_Lee*10;
            beta_m = m_Lee*(za_/z0_)+b_Lee;
            gamma_m = 15;
            R_m     = 0.85;
            zeta_m  = (za_/(dz))*log(za_/z0_)*(Rib/R_m)* 1/(1-beta_m*Rib);
            MO_L_   = za_/zeta_m;
            phi_m   = (1-gamma_m*za_/MO_L_)^(1/4);
            phi0_m  = (1-gamma_m*(z0_/MO_L_))^(1/4);
            psi_m_  = -2*log((1+phi_m)/(1+phi0_m))...
                      -log((1+phi_m^2)/(1+phi0_m^2))...
                      +2*tan(phi_m)^-1-2*tan(phi0_m)^-1;

        elseif Rib>=0
            beta_m = 4.7;
            R_m     = 0.74;
            zeta_m  = (za_/(dz))*log(za_/z0_)/...
                      (2*beta_m/R_m*(beta_m*Rib-1))*...
              (-2*beta_m/R_m*Rib+1-sqrt(1+4*beta_m*(1-R_m)*Rib/(R_m^2)));
            psi_m_  = beta_m*zeta_m;

        end

    elseif strcmp(AtmStbScheme,'Le97D')==1 && isnan(psi_m_)==1

        if Rib<0
            m_Lee   = (0.1-0.023)/(10^4-10);
            b_Lee   = 0.023-m_Lee*10;
            beta_m = m_Lee*(za_/z0_)+b_Lee;
            gamma_m = 16;
            zeta_m  = (za_/(dz))*log(za_/z0_)* Rib/(1-beta_m*Rib);
            MO_L_   = za_/zeta_m;
            phi_m   = (1-gamma_m*za_/MO_L_)^(1/4);
            phi0_m  = (1-gamma_m*(z0_/MO_L_))^(1/4);
            psi_m_  = -2*log((1+phi_m)/(1+phi0_m))...
                      -log((1+phi_m^2)/(1+phi0_m^2))...
                      +2*tan(phi_m)^-1-2*tan(phi0_m)^-1;

        elseif Rib>=0
            beta_m = 5;
            zeta_m  = (za_/(dz))*log(za_/z0_)*Rib/(1-beta_m*Rib);
            psi_m_  = beta_m.*zeta_m;

        end

    elseif strcmp(AtmStbScheme,'Stu88')==1 && isnan(psi_m_)==1

        zeta_m  = Rib;
        
        if zeta_m<0
            
            gamma_m = 15;
            phi_m   = (1-gamma_m*zeta_m)^(1/4);            
            psi_m_  = -2*log((1+phi_m)/2)-log((1+phi_m^2)/2)...
                      +2*tan(phi_m)^-1-pi/2;

        elseif zeta_m>=0
            beta_m = 4.7;
            psi_m_  = beta_m*zeta_m;

        end
        
    elseif strcmp(AtmStbScheme,'S&R75')==1 && isnan(psi_m_)==1

        dCelsius = Ta_-Tw_-Tcool-Twarm;
        
        if dCelsius>SR75_dT_range(1) && dCelsius<SR75_dT_range(2)
            CD   = (-0.4*(Ta_-Tw_-Tcool-Twarm)+1.5)*10^-3;
            u_   = uz_*sqrt(CD);
        else
            CD   = NaN;
            u_   = NaN;
            ['error at t=' num2str(t) ': Ta-Tw=' num2str(dCelsius) ...
                                             ' out of bounds for S&R75']
        end
        
    end
    
    u_=uz_*Karman/(log(za_)-log(z0_)+psi_m_);
    
end

%--------------------------------------------------------------------------
                            %CALCULUS
                % air transfer velocity (m/s)

switch KaScheme
    
    case 'Joh10'
        if u_~=0
            ka=10^-3+(uz_./u_.^2+5./u_.*Sca.^(2/3)).^-1;
        else
            ka=10^-3;
        end

    case 'Dea91'
        ka=uz_./(770+45*Mb^(1/3));
        
    case 'Lis73'
        ka=0.005+0.21*uz_./100;
        
    case 'M&Y83'
        ka=10^-3+46.2*10^-3*u_.*Sca.^(-2/3);
        
        
    case 'Sea02'
        ka=Da.^0.5*(0.98*uz_+1.26)./100;
        
    case 'J_COA'
        ka=10^-3+u_./(13.3*Sca.^(1/2)+CD.^(-1/2)-5+log(Sca)./0.8);
    case 'none '
        % do not use Ka scheme
        
end
