                                %OBJECTIVES:

%Estimates the water side transfer velocity for given temperatures (T),
% salinity (S), wind (uz), water current (w) and depth (z).

%--------------------------------------------------------------------------

                                %CALCULUS:
   %water temperature and salinity on chemical enhancement factor (alfa)


switch SchmidtScheme
    
    case 'Joh10'
        
        [msi,msj]=size(MassFraction);
        
        % Mass fraction of pure water
        Ww=(1000-S_)/1000;                                          %scalar

        %Dynamic viscosity of pure water
        Etaw0=(T+246)./(0.05594.*T.^2+5.2842.*T+137.37);          %mg/(m.s)

        % Mass fraction of the solutes
        Wi=cell2mat(MassFraction(2:msi,2))*S_./1000;                %scalar

        %Dynamic viscosity of solutes
        for i=1:msi-1
            v=cell2mat(MassFraction(i+1,3:msj));
            Etai(i,:)=exp((v(1)*(1-Ww).^v(2)+v(3))./(v(4).*T+1))...
                     ./(v(5)*(1-Ww).^v(6)+1);                     %mg/(m.s)
        end

        %Dynamic viscosity of marine water
        try
            Etawg=exp(Ww.*log(Etaw0)+Wi'*log(Etai));               %g/(m.s)
        catch   %for a test over a salinity array
            Etawg=exp(Ww.*log(Etaw0)+diag(Wi'*log(Etai))');        %g/(m.s)
        end
        EtawKg=Etawg./1000;                                       %kg/(m.s)

        %Water difusivity scheme ( cm^2/s)
        switch DwScheme
            case 'H&L74'
                Dw=13.26*10^-5./(Etawg.^1.4.*Vb^0.598);
                
            case 'H&M82'
                epsilon=9.58/Vb-1.12;
                Dw=1.25*10^-8.*Tkw.^1.52.*Etawg.^epsilon.*(Vb^-0.19-0.292); 
                
            case 'W&C55'
                Dw=7.4*10^-8.*Tkw*sqrt(phi*Ms)./(Etawg.*Vb^0.6);
        end

         % Pure water density
        Rhow0=r0+r1.*T+r2.*T.^2+r3.*T.^3+r4.*T.^4+r5.*T.^5;         %kg/m^3

        % Parameters a and b to estimate marine water density
        a=a0+a1.*T+a2.*T.^2+a3.*T.^3+a4.*T.^4;                      %scalar
        b=b0+b1.*T+b2.*T.^2;                                        %scalar

        % Marine water density
        Rhow=Rhow0+a*S_+b*S_.^(3/2)+c*S_;                           %kg/m^3
        
        %Kinematic viscosity of water converted from m^2/s to cm^2/s
        Upsw=EtawKg./Rhow*10000;

        %Schmidt number in water
        Scw=Upsw./Dw;                                               %scalar

    case 'Bea04'
        %Schmidt number of pure water at given temperature
        Sc0=1800.6-120.1.*T+3.7818.*T.^2-0.047608.*T.^3;
        
        %Schmidt number of water at 35 salinity at given temperature
        Sc35=1953.4-128.*T+3.9918.*T.^2-0.050091.*T.^3;
        
        %Schmidt number of water at given salinity and temperature
        Scw=(Sc35-Sc0).*S_/35+Sc0;
           
    case 'Cea96'
        %Schmidt number of water at given temperature
        Scw=2073.1-125.62.*T+3.6276.*T.^2-0.043219.*T.^3;
        
    case 'R&C01'
        %Schmidt number of water at given temperature
        Scw=2073.1-125.62.*T+3.6276.*T.^2-0.043219.*T.^3;
        
end

Alfa=sqrt(600./Scw);

if strcmp(KwScheme,'Wan92')==1 || strcmp(KwScheme,'Sea07')==1
    Alfa=sqrt(660./Scw);
end

%--------------------------------------------------------------------------

                                %CALCULUS:
             %current and depht on water transfer velocity
                     %by O'Connor & Dobbins (1958)

kwCurrent=1.719*sqrt(w_*100/z_);

%--------------------------------------------------------------------------

                                %CALCULUS:
                   %wind on water transfer velocity (kw)


switch KwScheme   

    case 'Bea04' 
        kwWind=(1+2.58*uz_);                                         %cm/h
           
    case 'Cea96'
        kwWind=0.045+2.0277*uz_;                                     %cm/h
    
    case 'L&M86'
        kwWind=0.075*uz_^2.25;                                       %cm/h
    
    case 'M&Y83'
        kwWind=(10^-4+34.1*10^-2*u_*Scw^-0.5)*60*60;                  %cm/h
        
    case 'MY83W'
        kwWind=(10^-4+144*10^-2*u_^2.2*Scw^-0.5)*60*60;               %cm/h
        
    case 'McG01'
        kwWind=3.3+0.026*uz_^3;                                      %cm/h
        
    case 'Nea00'
        kwWind=0.222*uz_^2+0.333*uz_;                               %cm/h
        
    case 'R&C01'
        kwWind=1.91*exp(0.35*uz_);                                   %cm/h
        
    case 'Sea07'
        kwWind=0.27*uz_^2;                                           %cm/h
        
    case 'Wan92'
        kwWind=0.31*uz_^2;                                           %cm/h
        
    case 'Zea03'
        kwWind=61.79*u_^1.22;                                         %cm/h
        
    case 'ZoJ03'
        kwWind=101.4*u_^1.88;                                         %cm/h
        
    case 'ZRb03'
        % Upsa converted back from cm^2/s to m^2/s
        Rb=u_^2/(2*pi/Wp_*Upsa/10000);
        kwWind= 0.1315*Rb^0.6322;                                     %cm/h
        
end

%--------------------------------------------------------------------------

                                %CALCULUS
                        %water transfer velocity

kw=(10^-6+kwWind+kwCurrent).*Alfa;                                    %cm/h

% conversion from cm/h to m/s
kw=kw./(100*3600);                                                     %m/s
